/*!
 * Angular Material Design
 * https://github.com/angular/material
 * @license MIT
 * v0.8.3
 */
.md-subheader.md-THEME_NAME-theme {
  color: '{{ foreground-2-0.23 }}';
  background-color: '{{background-hue-3}}'; }
  .md-subheader.md-THEME_NAME-theme.md-primary {
    color: '{{primary-color}}'; }
  .md-subheader.md-THEME_NAME-theme.md-accent {
    color: '{{accent-color}}'; }
  .md-subheader.md-THEME_NAME-theme.md-warn {
    color: '{{warn-color}}'; }
